@@ -23,12 +23,11 @@
 #ifndef _GVFSAFPVOLUME_H_
 #define _GVFSAFPVOLUME_H_
 
-#include <glib-object.h>
+#include "gvfsafptypes.h"
+#include "gvfsafpconnection.h"
 
 G_BEGIN_DECLS
 
-typedef struct _GVfsAfpServer GVfsAfpServer;
-
 #define G_VFS_TYPE_AFP_VOLUME             (g_vfs_afp_volume_get_type ())
 #define G_VFS_AFP_VOLUME(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_VFS_TYPE_AFP_VOLUME, GVfsAfpVolume))
 #define G_VFS_AFP_VOLUME_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), G_VFS_TYPE_AFP_VOLUME, GVfsAfpVolumeClass))
@@ -37,7 +36,6 @@ typedef struct _GVfsAfpServer GVfsAfpServer;
 #define G_VFS_AFP_VOLUME_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), G_VFS_TYPE_AFP_VOLUME, GVfsAfpVolumeClass))
 
 typedef struct _GVfsAfpVolumeClass GVfsAfpVolumeClass;
-typedef struct _GVfsAfpVolume GVfsAfpVolume;
 typedef struct _GVfsAfpVolumePrivate GVfsAfpVolumePrivate;
 
 struct _GVfsAfpVolumeClass
@@ -54,7 +52,7 @@ struct _GVfsAfpVolume
 
 GType g_vfs_afp_volume_get_type (void) G_GNUC_CONST;
 
-GVfsAfpVolume *g_vfs_afp_volume_new                 (GVfsAfpServer *server);
+GVfsAfpVolume *g_vfs_afp_volume_new                 (GVfsAfpServer *server, GVfsAfpConnection *conn);
 
 gboolean       g_vfs_afp_volume_mount_sync          (GVfsAfpVolume *volume,
                                                      const char    *volume_name,
@@ -162,18 +160,6 @@ gboolean     g_vfs_afp_volume_move_and_rename_finish (GVfsAfpVolume  *volume,
                                                       GAsyncResult   *res,
                                                       GError        **error);
 
-void          g_vfs_afp_volume_map_id              (GVfsAfpVolume       *volume,
-                                                    AfpMapIDFunction     map_function,
-                                                    gint64               id,
-                                                    GCancellable        *cancellable,
-                                                    GAsyncReadyCallback  callback,
-                                                    gpointer             user_data);
-
-char *        g_vfs_afp_volume_map_id_finish       (GVfsAfpVolume   *volume,
-                                                    GAsyncResult     *res,
-                                                    AfpMapIDFunction *map_function,
-                                                    GError          **error);
-
 void          g_vfs_afp_volume_get_filedir_parms   (GVfsAfpVolume       *volume,
                                                     const char          *filename,
                                                     guint16              file_bitmap,
